@@ -18,8 +18,8 @@ class Players(_Endpoint):
         """
         return self.POST("", {"username": name})
 
-    def get_player_by_id(self, id: int):
+    def get_player_by_id(self, user_id: int):
         """
         Get a player by their ID.
         """
-        return self.POST("", {"user_id": id})
+        return self.POST("", {"user_id": user_id})
